from pathlib import Path
from freebie.util import read_csv

__PROJECT_PATH = Path(__file__).parents[0]
__WEB_SOURCE_PATH = __PROJECT_PATH / 'websources.csv'
__RSS_FEEDS_PATH = __PROJECT_PATH / 'rss_feeds.csv'
__TWITTER_HANDLES_PATH = __PROJECT_PATH / 'twitter_handles.csv'


twitter_handles = read_csv(__TWITTER_HANDLES_PATH)
websources = read_csv(__WEB_SOURCE_PATH)
rss_feeds = read_csv(__RSS_FEEDS_PATH)



import csv


def read_csv(fp, header=None):
    table = []
    with open(fp, 'r', encoding='utf-8') as csvfile:
        csv_reader = csv.reader(csvfile, delimiter=',', quotechar='"')
        if not header:
            header = next(csv_reader)
        for row in csv_reader:
            new_row = {}
            for cell, col_name in zip(row, header):
                new_row[col_name] = cell
            table.append(new_row)
    return table



#!/usr/bin/env python
import os

from distutils.core import setup
from setuptools import find_packages

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

with open('requirements.txt') as fh:
    install_requires = fh.read().splitlines()

setup(
    name='freebie',
    version='0.1.1',
    description='A free database of news resources for information extraction',
    author='Aleksandar Savkov',
    packages=find_packages(exclude=('test',)),
    zip_safe=True,
    include_package_data=False,
    license='GPL3',
    install_requires=install_requires,
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP'
    ],
    package_data={
        'freebie.news': ['rss_feeds.csv', 'websources.csv'],
        'freebie.twitter': ['twitter_handles.csv']
    },
)
